==> xmail-0.64.tar.gz: xmail-0.64/MailSvr.h <==
/*
 *  MailSvr by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davide_libenzi@mycio.com>
 *
 */


#ifndef _MAILSVR_H
#define _MAILSVR_H





///////////////////////////////////////////////////////////////////////////////
//  Defined in MailSvr.cpp
///////////////////////////////////////////////////////////////////////////////
extern SharedBlock SHB_CTRLSvr,
                SHB_FINGSvr,
                SHB_SMTPSvr,
                SHB_SMAILSvr,
                SHB_POP3Svr,
                SHB_PSYNCSvr;
extern char     szMailPath[SYS_MAX_PATH];
extern unsigned int uKeyMagic;
extern SYS_IPCNAME SemPSYNCThreads;
extern bool     bServerDebug;
extern int      iLogRotateDays;
extern int      iQueueSplitLevel;






int             SvrMain(int iArgCount, char *pszArgs[]);
int             SvrStopServer(bool bWait = true);
bool            SvrInShutdown(void);
int             SvrShutdownCB(void * pData);





#endif

==> xmail-1.9.tar.gz: xmail-1.9/MailSvr.h <==
/*
 *  XMail by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999,...,2002  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davidel@xmailserver.org>
 *
 */


#ifndef _MAILSVR_H
#define _MAILSVR_H





///////////////////////////////////////////////////////////////////////////////
//  Defined in MailSvr.cpp
///////////////////////////////////////////////////////////////////////////////
extern SHB_HANDLE hShbFING,
                hShbCTRL,
                hShbPOP3,
                hShbSMTP,
                hShbSMAIL,
                hShbPSYNC,
                hShbLMAIL;
extern char     szMailPath[SYS_MAX_PATH];
extern bool     bServerDebug;
extern QUEUE_HANDLE hSpoolQueue;
extern SYS_SEMAPHORE hSyncSem;
extern int      iLogRotateHours;
extern int      iQueueSplitLevel;






int             SvrMain(int iArgCount, char *pszArgs[]);
int             SvrStopServer(bool bWait = true);
bool            SvrInShutdown(bool bForceCheck = false);




#endif
